@@ -1,5 +1,5 @@
 "savematrix" <-
-structure(function(n,filename,twomode=1,cont=FALSE){
+structure(function(n,filename,twomode=1){
 if(length(grep(pattern="w32",x=version["os"]))){
 	eol<-"\n"
 }else{eol<-"\r\n"}
@@ -14,7 +14,7 @@ if ((dim(n)[1] == dim(n)[2]) & (twomode!=2))
   		verNames[verNames==i]<-paste(i,1:verNamesTable[i],sep="")
   	}
   }
-  cat(paste("*Vertices",dim(n)[1]),eol, file = filename,append=cont);
+  cat(paste("*Vertices",dim(n)[1]),eol, file = filename);
   cat(paste(seq(1,length=dim(n)[1]),' "',verNames,'"',eol,sep=""), file = filename,append=TRUE);
   cat("*Matrix",eol, file = filename,append=TRUE);
   write.table(n,file=filename,eol=eol,row.names = FALSE, col.names = FALSE,append=TRUE)
@@ -38,7 +38,7 @@ if ((dim(n)[1] == dim(n)[2]) & (twomode!=2))
   		verColNames[verColNames==i]<-paste(i,1:verColNamesTable[i],sep="")
   	}
   }
-  cat(paste("*Vertices",sum(dim(n)),dim(n)[1]),eol, file = filename,append=cont);
+  cat(paste("*Vertices",sum(dim(n)),dim(n)[1]),eol, file = filename);
   cat(paste(1:dim(n)[1],' "',verRowNames,'"',eol,sep=""), file = filename,append=TRUE);
   cat(paste(seq(dim(n)[1]+1,length=dim(n)[2]),' "',verColNames,'"',eol,sep=""), file = filename,append=TRUE);
   cat("*Matrix",eol, file = filename, append=TRUE);
